
#ifndef PLFIT_EXPORT_H
#define PLFIT_EXPORT_H

#ifdef PLFIT_STATIC
#  define PLFIT_EXPORT
#  define PLFIT_NO_EXPORT
#else
#  ifndef PLFIT_EXPORT
#    ifdef plfit_EXPORTS
        /* We are building this library */
#      define PLFIT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PLFIT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PLFIT_NO_EXPORT
#    define PLFIT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PLFIT_DEPRECATED
#  define PLFIT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PLFIT_DEPRECATED_EXPORT
#  define PLFIT_DEPRECATED_EXPORT PLFIT_EXPORT PLFIT_DEPRECATED
#endif

#ifndef PLFIT_DEPRECATED_NO_EXPORT
#  define PLFIT_DEPRECATED_NO_EXPORT PLFIT_NO_EXPORT PLFIT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PLFIT_NO_DEPRECATED
#    define PLFIT_NO_DEPRECATED
#  endif
#endif

#endif /* PLFIT_EXPORT_H */
